@@ -281,6 +281,7 @@ async def test_app_handle_request_asyncio_cancelled_error() -> None:
         Headers([("host", "quart.com")]),
         "",
         "1.1",
+        {},
         send_push_promise=no_op_push,
     )
     with pytest.raises(asyncio.CancelledError):
@@ -296,7 +297,7 @@ async def test_app_handle_websocket_asyncio_cancelled_error() -> None:
         raise asyncio.CancelledError()
 
     websocket = app.websocket_class(
-        "/", b"", "wss", Headers([("host", "quart.com")]), "", "1.1", None, None, None, None
+        "/", b"", "wss", Headers([("host", "quart.com")]), "", "1.1", None, None, None, None, {}
     )
     with pytest.raises(asyncio.CancelledError):
         await app.handle_websocket(websocket)
@@ -377,3 +378,32 @@ async def test_propagation(debug: bool, testing: bool, raises: bool) -> None:
     else:
         response = await test_client.get("/")
         assert response.status_code == 500
+
+
+@pytest.mark.asyncio
+async def test_test_app() -> None:
+    startup = False
+    shutdown = False
+
+    app = Quart(__name__)
+
+    @app.before_serving
+    async def before() -> None:
+        nonlocal startup
+        startup = True
+
+    @app.after_serving
+    async def after() -> None:
+        nonlocal shutdown
+        shutdown = True
+
+    @app.route("/")
+    async def index() -> str:
+        return ""
+
+    async with app.test_app() as test_app:
+        assert startup
+        test_client = test_app.test_client()
+        await test_client.get("/")
+        assert not shutdown
+    assert shutdown
